@@ -7,7 +7,7 @@ OC.L10N.register(
     "Delete" : "Löschen",
     "Tags" : "Schlagworte",
     "Show list view" : "Listenansicht anzeigen",
-    "Show grid view" : "Rasteransicht anzeigen",
+    "Show grid view" : "Kachelansicht anzeigen",
     "Home" : "Home",
     "Close" : "Schließen",
     "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
@@ -101,12 +101,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Ihr Speicher ist beinahe voll ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["stimmt mit \"{filter}\" überein","stimmen mit \"{filter}\" überein"],
     "View in folder" : "In Ordner anzeigen",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Benutzer, die Zugriff auf diese Datei/Ordner haben)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
     "Path" : "Pfad",
     "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
     "Favorited" : "Favorisiert",
     "Favorite" : "Favorit",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Benutzer, die Zugriff auf diese(n) Datei/Ordner haben)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Personen, die Zugriff auf diese Datei bzw. den Ordner haben)",
     "New folder" : "Neuer Ordner",
     "Create new folder" : "Neuen Ordner erstellen",
     "Upload file" : "Datei hochladen",
@@ -127,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "Wiederhergestellt durch {user}",
     "Renamed by {user}" : "Umbenannt durch {user}",
     "Moved by {user}" : "Verschoben durch {user}",
-    "\"remote user\"" : "„Externer Benutzer“",
+    "\"remote account\"" : "\"Entferntes Konto\"",
     "You created {file}" : "Sie haben {file} erstellt",
     "You created an encrypted file in {file}" : "Sie haben eine verschlüsselte Datei in {file} erstellt",
     "{user} created {file}" : "{user} hat {file} erstellt",
@@ -175,7 +175,6 @@ OC.L10N.register(
     "Drag and drop files here to upload" : "Dateien zum Hochladen hierher ziehen und ablegen",
     "Your have used your space quota and cannot upload files anymore" : "Ihr Speicherplatzkontigent ist aufgebraucht, Sie können keine weiteren Dateien hochladen",
     "You don’t have permission to upload or create files here" : "Sie haben keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
-    "Upload successful" : "Hochladen erfolgreich",
     "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" erfolgreich ausgeführt",
     "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
     "Toggle selection for file \"{displayName}\"" : "Auswahl für die Datei \"{displayName}\" umschalten",
@@ -185,6 +184,7 @@ OC.L10N.register(
     "Folder name" : "Ordnername",
     "This node is unavailable" : "Dieser Knoten ist nicht verfügbar",
     "Download file {name}" : "Datei {name} herunterladen",
+    "Invalid file name" : "Ungültiger Dateiname",
     "\"{name}\" is not an allowed filetype." : "\"{name}\" ist kein zulässiger Dateityp.",
     "{newName} already exists." : "{newName} existiert bereits.",
     "\"{char}\" is not allowed inside a file name." : "\"{char}“ ist innerhalb eines Dateinamens nicht zulässig.",
@@ -194,12 +194,11 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" konnte nicht umbenannt werden, da es nicht mehr existiert",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}“ wird bereits im Ordner \"{dir}“ verwendet. Bitte wählen Sie einen anderen Namen.",
     "Could not rename \"{oldName}\"" : "\"{oldName}\" konnte nicht umbenannt werden",
-    "Could not copy {file}. {message}" : "{file} konnte nicht kopiert werden. {message}",
-    "Could not move {file}. {message}" : "{file} konnte nicht verschoben werden. {message}",
     "Total rows summary" : "Zusammenfassung aller Zeilen",
     "Toggle selection for all files and folders" : "Auswahl für alle Dateien und Ordner umschalten",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
     "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" erfolgreich ausgeführt",
+    "{count} selected" : "{count} ausgewählt",
     "List of files and folders." : "Liste der Dateien und Ordner.",
     "Column headers with buttons are sortable." : "Spaltenüberschriften mit Schaltflächen sind sortierbar.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Diese Liste ist aus Performance-Gründen nicht vollständig gerendert. Die Dateien werden gerendert, wenn Sie durch die Liste navigieren.",
@@ -209,6 +208,8 @@ OC.L10N.register(
     "{relative}% used" : "{relative}% verwendet",
     "Could not refresh storage stats" : "Die Speicherstatistik konnte nicht aktualisiert werden",
     "Your storage is full, files can not be updated or synced anymore!" : "Ihr Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
+    "Create" : "Erstellen",
+    "A file or folder with that name already exists." : "Eine Datei oder ein Ordner mit diesem Namen existiert bereits.",
     "Transfer ownership of a file or folder" : "Besitz einer Datei oder eines Ordners übertragen",
     "Choose file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
     "Change" : "Ändern",
@@ -223,7 +224,6 @@ OC.L10N.register(
     "Select file or folder to link to" : "Datei oder Ordner zum Verknüpfen auswählen",
     "Choose file" : "Datei auswählen",
     "Choose {file}" : "{file} auswählen",
-    "Add" : "Hinzufügen",
     "Loading current folder" : "Lade aktuellen Ordner",
     "No files in here" : "Keine Dateien vorhanden",
     "Upload some content or sync with your devices!" : "Laden Sie Inhalte hoch oder synchronisieren Sie Ihre Geräte!",
@@ -233,7 +233,7 @@ OC.L10N.register(
     "Shared by link" : "Über einen Link geteilt",
     "Shared" : "Geteilt",
     "Switch to list view" : "Zur Listenansicht wechseln",
-    "Switch to grid view" : "Zur Rasteransicht wechseln",
+    "Switch to grid view" : "Zur Kachelansicht wechseln",
     "Error during upload: {message}" : "Fehler beim Hochladen: {message}",
     "Error during upload, status code {status}" : "Fehler beim Hochladen, Statuscode {status}",
     "Unknown error during upload" : "Unbekannter Fehler beim Hochladen",
@@ -241,11 +241,13 @@ OC.L10N.register(
     "Files settings" : "Dateien-Einstellungen",
     "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Die Datei konnte nicht gefunden werden oder Sie haben keine Berechtigungen, um sie anzuzeigen. Bitten Sie den Absender, die Datei zu teilen.",
+    "Your files" : "Ihre Dateien",
+    "Open in files" : "In Dateien öffnen",
     "Sort favorites first" : "Favoriten zuerst sortieren",
     "Sort folders before files" : "Ordner vor Dateien sortieren",
     "Show hidden files" : "Versteckte Dateien anzeigen",
     "Crop image previews" : "Bildvorschauen zuschneiden",
-    "Enable the grid view" : "Rasteransicht aktivieren",
+    "Enable the grid view" : "Kachelansicht aktivieren",
     "Additional settings" : "Zusätzliche Einstellungen",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV-URL",
@@ -257,19 +259,28 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Der favorisierte Status der Datei kann nicht geändert werden",
     "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
     "Pick a template for {name}" : "Eine Vorlage für {name} wählen",
-    "Create" : "Erstellen",
     "Create a new file with the selected template" : "Eine neue Datei anhand der ausgewählten Vorlage erstellen",
     "Creating file" : "Datei erstellen",
     "Blank" : "Leer",
     "Unable to create new file from template" : "Neue Datei kann nicht aus Vorlage erstellt werden",
     "Delete permanently" : "Endgültig löschen",
+    "Delete and unshare" : "Löschen und nicht mehr teilen",
+    "Leave these shares" : "Diese Freigaben verlassen",
+    "Disconnect storages" : "Speicher trennen",
+    "Delete files" : "Dateien löschen",
+    "Delete folders" : "Ordner löschen",
+    "You are about to delete {count} items." : "Sie sind dabei, {count} Elemente zu löschen.",
+    "Confirm deletion" : "Löschen bestätigen",
+    "Cancel" : "Abbrechen",
+    "Deletion cancelled" : "Löschen abgebrochen",
     "Destination is not a folder" : "Ziel ist kein Ordner",
     "This file/folder is already in that directory" : "Diese Datei oder Ordner ist bereits in diesem Verzeichnis vorhanden",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Eine Datei oder ein Ordner kann nicht auf sich selbst oder in einen Unterordner von sich selbst verschoben werden",
     "(copy)" : "(kopieren)",
     "(copy %n)" : "(%n kopieren)",
+    "Move cancelled" : "Verschieben abgebrochen",
     "A file or folder with that name already exists in this folder" : "In diesem Ordner ist bereits eine Datei oder ein Ordner mit diesem Namen vorhanden",
-    "The files is locked" : "Die Datei ist gesperrt",
+    "The files are locked" : "Die Dateien sind gesperrt",
     "The file does not exist anymore" : "Diese Datei existiert nicht mehr",
     "Choose destination" : "Ziel wählen",
     "Copy to {target}" : "Nach {target} kopieren",
@@ -279,12 +290,27 @@ OC.L10N.register(
     "Open folder {displayName}" : "Ordner {displayName} öffnen",
     "Open in Files" : "In Dateien öffnen",
     "Open details" : "Details öffnen",
+    "Created new folder \"{name}\"" : "Neuer Ordner \"{name}\" wurde erstellt",
+    "Filename" : "Dateiname",
+    "Unable to initialize the templates directory" : "Der Vorlagenordner kann nicht initialisiert werden",
     "Create new templates folder" : "Neuen Vorlagenordner erstellen",
     "Templates" : "Vorlagen",
-    "Unable to initialize the templates directory" : "Der Vorlagenordner kann nicht initialisiert werden",
-    "Created new folder \"{name}\"" : "Neuer Ordner \"{name}\" wurde erstellt",
+    "New template folder" : "Neuer Vorlagenordner",
+    "In folder" : "Im Ordner",
+    "Search in folder: {folder}" : "Im Ordner suchen: {folder}",
     "One of the dropped files could not be processed" : "Eine der abgelegten Dateien konnte nicht verarbeitet werden",
-    "Uploading \"{filename}\" failed" : "Fehler beim Hochladen von \"{filename}\"",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ihr Browser unterstützt die Dateisystem-API nicht. Verzeichnisse werden nicht hochgeladen",
+    "No files to upload" : "Keine Dateien zum Hochladen",
+    "Unable to create the directory {directory}" : "Der Ordner {directory} konnte nicht erstellt werden",
+    "Some files could not be uploaded" : "Einige Dateien konnten nicht hochgeladen werden.",
+    "Files uploaded successfully" : "Dateien hochgeladen",
+    "No files to process" : "Keine Dateien zum Verarbeiten",
+    "Some files could not be copied" : "Einige Dateien konnten nicht kopiert werden",
+    "Some files could not be moved" : "Einige Dateien konnten nicht verschoben werden",
+    "Files copied successfully" : "Dateien kopiert",
+    "Files moved successfully" : "Dateien verschoben",
+    "Conflicts resolution skipped" : "Konfliktelösung übersprungen",
+    "Upload cancelled" : "Hochladen abgebrochen",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} Ordner","{folderCount} Ordner"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} Datei","{fileCount} Dateien"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 Datei und {folderCount} Ordner","1 Datei und {folderCount} Ordner"],
@@ -295,6 +321,10 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die Sie als Favoriten kennzeichnen, werden hier erscheinen",
     "All files" : "Alle Dateien",
     "List of your files and folders." : "Liste Ihrer Dateien und Ordner.",
+    "Personal Files" : "Persönliche Dateien",
+    "List of your files and folders that are not shared." : "Liste Ihrer Dateien und Ordner, die nicht geteilt wurden.",
+    "No personal files found" : "Keine persönlichen Dateien gefunden",
+    "Files that are not shared will show up here." : "Dateien, die nicht geteilt wurden, werden hier angezeigt.",
     "List of recently modified files and folders." : "Liste der zuletzt geänderten Dateien und Ordner.",
     "No recently modified files" : "Keine kürzlich geänderten Dateien",
     "Files and folders you recently modified will show up here." : "Die von Ihnen kürzlich geänderten Dateien und Ordner werden hier angezeigt.",
@@ -304,21 +334,12 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
     "Text file" : "Textdatei",
     "New text file.txt" : "Neue Textdatei file.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Benutzer, die Zugriff auf diese Datei/Ordner haben)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Benutzer, die Zugriff auf diese(n) Datei/Ordner haben)",
     "You can only favorite a single file or folder at a time" : "Sie können gleichzeitig nur eine Datei oder einen Ordner als Favorit markieren",
-    "Search users" : "Suche Benutzer",
-    "You might not have have permissions to view it, ask the sender to share it" : "Möglicherweise haben Sie nicht die Berechtigung zur Anzeige. Bitten Sie den Absender, die Datei freizugeben.",
-    "Cancel" : "Abbrechen",
-    "Set up templates folder" : "Vorlagenordner einrichten",
-    "Toggle %1$s sublist" : "Unterliste %1$s umschalten",
-    "Toggle grid view" : "Rasteransicht umschalten",
-    "Deleted files" : "Gelöschte Dateien",
-    "Shares" : "Freigaben",
-    "Shared with others" : "Mit anderen geteilt",
-    "Shared with you" : "Mit Ihnen geteilt",
-    "Deleted shares" : "Gelöschte Freigaben",
-    "Pending shares" : "Ausstehende Freigaben",
     "This file has the tag {tag}" : "Diese Datei trägt das Schlagwort {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Diese Datei trägt die Schlagworte {firstTags} und {lastTag}",
+    "\"remote user\"" : "„Externer Benutzer“",
     "Select the row for {displayName}" : "Zeile für {displayName} auswählen",
     "Open folder {name}" : "Ordner {name} öffnen",
     "Unselect all" : "Auswahl aufheben",
@@ -328,6 +349,16 @@ OC.L10N.register(
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Diese Liste ist aus Performance-Gründen nicht vollständig gerendert. Die Dateien werden gerendert, wenn Sie durch die Liste navigieren.",
     "Search for an account" : "Nach einem Konto suchen",
     "Choose" : "Auswählen",
-    "No files or folders have been deleted yet" : "Es wurden noch keine Dateien oder Ordner gelöscht"
+    "No files or folders have been deleted yet" : "Es wurden noch keine Dateien oder Ordner gelöscht",
+    "You might not have have permissions to view it, ask the sender to share it" : "Möglicherweise haben Sie nicht die Berechtigung zur Anzeige. Bitten Sie den Absender, die Datei freizugeben.",
+    "Set up templates folder" : "Vorlagenordner einrichten",
+    "Toggle %1$s sublist" : "Unterliste %1$s umschalten",
+    "Toggle grid view" : "Kachelansicht umschalten",
+    "Shares" : "Freigaben",
+    "Shared with others" : "Mit anderen geteilt",
+    "Shared with you" : "Mit Ihnen geteilt",
+    "Deleted shares" : "Gelöschte Freigaben",
+    "Pending shares" : "Ausstehende Freigaben",
+    "The files is locked" : "Die Datei ist gesperrt"
 },
 "nplurals=2; plural=(n != 1);");
