@@ -37,7 +37,7 @@ OC.L10N.register(
     "Set reminder" : "Ezarri abisua",
     "Edit locally" : "Editatu lokalean",
     "Open" : "Ireki",
-    "Delete file" : "Ezabatu fitxategia",
+    "Delete file" : "Fitxategia ezabatu",
     "Delete folder" : "Ezabatu karpeta",
     "Disconnect storage" : "Deskonektatu biltegia",
     "Leave this share" : "Utzi partekatze hau",
@@ -101,12 +101,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Zure biltegia betetzear dago ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["\"{filter}\" emaitza","\"{filter}\" emaitza"],
     "View in folder" : "Ikusi karpetan",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Esteka zuzena kopiatu da (fitxategi/karpeta honetara sarbidea duten erabiltzaileentzat bakarrik balio du)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Esteka zuzena kopiatu da (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
     "Path" : "Bidea",
     "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
     "Favorited" : "Gogoko gisa markatua",
     "Favorite" : "Gogokoa",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea duten erabiltzaileentzat bakarrik balio du)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
     "New folder" : "Karpeta berria",
     "Create new folder" : "Sortu karpeta berria",
     "Upload file" : "Igo fitxategia",
@@ -127,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "{user} erabiltzaileak leheneratua",
     "Renamed by {user}" : "{user} erabiltzaileak berrizendatua",
     "Moved by {user}" : "{user} erabiltzaileak lekuz aldatua",
-    "\"remote user\"" : "\"urruneko erabiltzailea\"",
+    "\"remote account\"" : "Urrutiko kontua",
     "You created {file}" : "{file} sortu duzu",
     "You created an encrypted file in {file}" : "{file} karpetan enkriptatutako fitxategi bat sortu duzu",
     "{user} created {file}" : "{user} erabiltzaileak {file} sortu du",
@@ -169,13 +169,16 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "{path}(r)en jabetza {user} erabiltzailetik transferitzea osatu da.",
     "in %s" : "%s(e)n",
     "File Management" : "Fitxategi-kudeaketa",
+    "Current directory path" : "Uneko direktorio-bidea",
     "Reload current directory" : "Birkargatu uneko direktorioa",
     "Go to the \"{dir}\" directory" : "Joan \"{dir}\" direktoriora",
     "Drag and drop files here to upload" : "Jaregin fitxategiak hemen igotzeko",
+    "Your have used your space quota and cannot upload files anymore" : "Zure espazio-kuota erabili duzu eta ezin duzu fitxategi gehiago kargatu",
     "You don’t have permission to upload or create files here" : "Ez duzu baimenik fitxategiak hona kargatu edo hemen sortzeko",
-    "Upload successful" : "Igoera ongi burutu da",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
     "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
+    "Toggle selection for file \"{displayName}\"" : "Ordeztu hautatutakoa  \"{displayName}\" fitxategiarekin",
+    "Toggle selection for folder \"{displayName}\"" : "Ordeztu hautatutakoa  \"{displayName}\" karpetarekin",
     "Rename file" : "Berrizendatu fitxategia",
     "File name" : "Fitxategi izena",
     "Folder name" : "Karpetaren izena",
@@ -190,12 +193,12 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Ezin izan da \"{oldName}\" berrizendatu, ez da existitzen dagoeneko",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" izena \"{dir}\" karpetan dagoeneko erabiltzen da. Mesedez aukeratu beste izen bat.",
     "Could not rename \"{oldName}\"" : "Ezin izan da \"{oldName}\" berrizendatu ",
-    "Could not copy {file}. {message}" : "Ezin izan da {file} kopiatu. {message}",
-    "Could not move {file}. {message}" : "Ezin izan da {file} mugitu. {message}",
     "Total rows summary" : "Errenkaden guztirako laburpena",
+    "Toggle selection for all files and folders" : "Ordeztu hautatutako fitxategi eta karpeta guztiak",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\"-k huts egin du elementu batzuetan",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" multzoko ekintza behar bezala exekutatu da",
     "List of files and folders." : "Fitxategi eta karpeten zerrenda.",
+    "Column headers with buttons are sortable." : "Botoiak dituzten zutabeen goiburuak ordena daitezke.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
     "File not found" : "Ez da fitxategia aurkitu",
     "Storage informations" : "Biltegiaren informazioak",
@@ -203,6 +206,8 @@ OC.L10N.register(
     "{relative}% used" : "%{relative} erabilita",
     "Could not refresh storage stats" : "Ezin izan da biltegiratze maila freskatu",
     "Your storage is full, files can not be updated or synced anymore!" : "Zure biltegia beteta dago, ezin duzu fitxategirik igo edo sinkronizatu jada!",
+    "Create" : "Sortu",
+    "A file or folder with that name already exists." : "Badago izen hori duen fitxategi edo karpeta.",
     "Transfer ownership of a file or folder" : "Transferitu fitxategiaren edo karpetaren jabetza",
     "Choose file or folder to transfer" : "Aukeratu fitxategia edo karpeta transferitzeko",
     "Change" : "Aldatu",
@@ -215,8 +220,8 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Jabetza transferentzia eskaera bidalita",
     "Cannot transfer ownership of a file or folder you do not own" : "Ezin da zurea ez den fitxategi edo karpeta baten jabetza transferitu",
     "Select file or folder to link to" : "Hautatu estekatzeko fitxategia edo karpeta",
+    "Choose file" : "Aukeratu fitxategia",
     "Choose {file}" : "Aukeratu {file}",
-    "Add" : "Gehitu",
     "Loading current folder" : "Uneko karpeta kargatzen",
     "No files in here" : "Ez dago fitxategirik hemen",
     "Upload some content or sync with your devices!" : "Igo edukiren bat edo sinkronizatu zure gailuekin!",
@@ -226,14 +231,24 @@ OC.L10N.register(
     "Shared by link" : "Esteka bidez partekatuta",
     "Shared" : "Partekatuta",
     "Switch to list view" : "Aldatu zerrenda ikuspegira",
+    "Switch to grid view" : "Aldatu sareta ikuspegira",
+    "Error during upload: {message}" : "Errorea igotzean: {message}",
+    "Error during upload, status code {status}" : "Errore bat gertatu da igotzean, {status} egoera kodea",
+    "Unknown error during upload" : "Errore ezezaguna igotzean",
     "Open the files app settings" : "Ireki Fitxategiak aplikazioaren ezarpenak",
     "Files settings" : "FItxategien ezarpenak",
     "File cannot be accessed" : "Ezin da fitxategia atzitu",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Ezin izan da fitxategia aurkitu edo ez duzu ikusteko baimenik. Eskatu bidaltzaileari partekatzeko.",
+    "Your files" : "Zure fitxategiak",
+    "Open in files" : "Ireki Fitxategiak aplikazioan",
     "Sort favorites first" : "Ordenatu gogokoak lehenengo",
+    "Sort folders before files" : "Ordenatu karpetak fitxategien aurretik",
     "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
     "Crop image previews" : "Moztu irudien aurrebistak",
+    "Enable the grid view" : "Gaitu sareta ikuspegira",
     "Additional settings" : "Ezarpen gehiago",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV URLa",
     "Copy to clipboard" : "Kopiatu arbelera",
     "Use this address to access your Files via WebDAV" : "Erabili helbide hau WebDAV bidez zure fitxategietara sartzeko",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FA gaitu baduzu, aplikazioaren pasahitz berria sortu eta erabili behar duzu hemen klik eginez.",
@@ -242,28 +257,58 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Ezin da fitxategiaren gogoko egoera aldatu",
     "Error while loading the file data" : "Errorea fitxategiaren datuak kargatzerakoan",
     "Pick a template for {name}" : "Hautatu {name}(r)entzako txantiloia",
-    "Create" : "Sortu",
     "Create a new file with the selected template" : "Sortu fitxategi berria hautatutako txantiloiarekin",
     "Creating file" : "Fitxategia sortzen",
     "Blank" : "Hutsik",
     "Unable to create new file from template" : "Ezin da fitxategi berria sortu txantiloitik",
     "Delete permanently" : "Ezabatu betirako",
+    "Delete and unshare" : "Ezabatu eta kendu partekatzea",
+    "Leave these shares" : "Utzi partekatze hauek",
+    "Disconnect storages" : "Deskonektatu biltegiak",
+    "Delete files" : "Ezabatu fitxategiak",
+    "Delete folders" : "Ezabatu karpetak",
+    "You are about to delete {count} items." : "{count} elementu ezabatzera zoaz.",
+    "Confirm deletion" : "Berretsi ezabaketa",
+    "Cancel" : "Utzi",
+    "Deletion cancelled" : "Ezabatzea bertan behera utzi da",
     "Destination is not a folder" : "Helburua ez da karpeta bat",
     "This file/folder is already in that directory" : "Fitxategi/karpeta hau dagoeneko karpeta horretan dago",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Ezin duzu fitxategi/karpeta bat berera edo bere azpikarpeta batera mugitu",
+    "(copy)" : "(kopiatu)",
+    "(copy %n)" : "(kopiatu %n)",
+    "Move cancelled" : "Mugimendua bertan behera utzi da",
     "A file or folder with that name already exists in this folder" : "Izen hori duen fitxategi edo karpeta bat dago karpena honetan",
-    "The files is locked" : "Fixategiak blokeatuta dago",
+    "The files are locked" : "Fitxategiak blokeatuta daude",
     "The file does not exist anymore" : "Fitxategia ez da existizen dagoeneko",
+    "Choose destination" : "Aukeratu helburua",
     "Copy to {target}" : "Kopiatu hona: {target}",
     "Move to {target}" : "Mugitu hona: {target}",
     "Cancelled move or copy operation" : "Mugitze edo kopiatze operazioa utzi da",
+    "Move or copy operation failed" : "Mugitzeko edo kopiatzeko eragiketak huts egin du",
     "Open folder {displayName}" : "Ireki {displayName} karpeta",
     "Open in Files" : "Ireki Fitxategiak aplikazioan",
     "Open details" : "Ireki xehetasunak",
+    "Created new folder \"{name}\"" : "\"{name}\" karpeta berria sortu da",
+    "Filename" : "Fitxategi-izena",
+    "Unable to initialize the templates directory" : "Ezin da txantiloien direktorioa hasieratu",
     "Create new templates folder" : "Sortu txantiloi karpeta berria",
     "Templates" : "Txantiloiak",
-    "Unable to initialize the templates directory" : "Ezin da txantiloien direktorioa hasieratu",
-    "Created new folder \"{name}\"" : "\"{name}\" karpeta berria sortu da",
+    "New template folder" : "Txantiloien karpeta berria",
+    "In folder" : "Karpetan",
+    "Search in folder: {folder}" : "Bilatu {folder} karpetan",
+    "One of the dropped files could not be processed" : "Jaregindako fitxategietako bat ezin izan da prozesatu",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Zure nabigatzaileak ez du Filesystem APIa onartzen. Direktorioak ez dira igoko",
+    "No files to upload" : "Ez dago igotzeko fitxategirik",
+    "Unable to create the directory {directory}" : "Ezin da {direktorioa} direktorioa sortu",
+    "Some files could not be uploaded" : "Fitxategi batzuk ezin izan dira igo",
+    "Files uploaded successfully" : "Fitxategiak behar bezala igo dira",
+    "No files to process" : "Ez dago prozesatzeko fitxategirik",
+    "Some files could not be copied" : "Fitxategi batzuk ezin izan dira kopiatu",
+    "Some files could not be moved" : "Fitxategi batzuk ezin izan dira mugitu",
+    "Files copied successfully" : "Fitxategiak behar bezala kopiatu dira",
+    "Files moved successfully" : "Fitxategiak behar bezala mugitu dira",
+    "Conflicts resolution skipped" : "Gatazkak konpontzea saihestu da",
+    "Upload cancelled" : "Igotzea bertan behera utzi da",
     "_{folderCount} folder_::_{folderCount} folders_" : ["Karpeta {folderCount}","{folderCount} karpeta"],
     "_{fileCount} file_::_{fileCount} files_" : ["Fitxategi {fileCount}","{fileCount} fitxategi"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["Fitxategi 1 eta karpeta {folderCount}","Fitxategi 1 eta {folderCount} karpeta"],
@@ -274,6 +319,10 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpetak hemen agertuko dira",
     "All files" : "Fitxategi guztiak",
     "List of your files and folders." : "Zure fitxategi eta karpeten zerrenda.",
+    "Personal Files" : "Fitxategi pertsonalak",
+    "List of your files and folders that are not shared." : "Partekatu ez diren zure fitxategi eta karpeten zerrenda.",
+    "No personal files found" : "Ez dago fitxategi pertsonalik",
+    "Files that are not shared will show up here." : "Partekatu ez dituzun fitxategiak hemen agertuko dira",
     "List of recently modified files and folders." : "Azkenaldian aldatutako fitxategi eta karpeten zerrenda.",
     "No recently modified files" : "Ez dago azkenaldian aldatutako fitxategirik",
     "Files and folders you recently modified will show up here." : "Azkenaldian aldatu dituzun fitxategi eta karpetak hemen agertuko dira.",
@@ -283,21 +332,12 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Igotzen saiatzen ari zaren fitxategiek zerbitzari honek onartzen duen gehienezko tamaina gainditzen dute.",
     "Text file" : "Testu-fitxategia",
     "New text file.txt" : "Testu-fitxategi berria.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Esteka zuzena kopiatu da (fitxategi/karpeta honetara sarbidea duten erabiltzaileentzat bakarrik balio du)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea duten erabiltzaileentzat bakarrik balio du)",
     "You can only favorite a single file or folder at a time" : "Fitxategi edo karpeta bakarra markatu dezakezu gogoko gisa aldiko",
-    "Search users" : "Bilatu erabiltzaileak",
-    "You might not have have permissions to view it, ask the sender to share it" : "Baliteke hura ikusteko baimenik ez izatea; eskatu igorleari partekatzeko",
-    "Cancel" : "Utzi",
-    "Set up templates folder" : "Konfiguratu txantiloien karpeta",
-    "Toggle %1$s sublist" : "Txandakatu %1$sazpizerrenda",
-    "Toggle grid view" : "Txandakatu sareta ikuspegia",
-    "Deleted files" : "Ezabatutako fitxategiak",
-    "Shares" : "Partekatzeak",
-    "Shared with others" : "Besteekin partekatuta",
-    "Shared with you" : "Zurekin partekatuta",
-    "Deleted shares" : "Ezabatutako partekatzeak",
-    "Pending shares" : "Zain dauden partekatzeak",
     "This file has the tag {tag}" : "Fitxategi honek {tag} etiketa dauka",
     "This file has the tags {firstTags} and {lastTag}" : "Fitxategi honek {firstTags} eta {lastTag} etiketak ditu",
+    "\"remote user\"" : "\"urruneko erabiltzailea\"",
     "Select the row for {displayName}" : "Hautatu {displayName} errenkada",
     "Open folder {name}" : "Ireki {name} karpeta",
     "Unselect all" : "Desautatu dena",
@@ -307,6 +347,16 @@ OC.L10N.register(
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
     "Search for an account" : "Bilatu kontu bat",
     "Choose" : "Aukeratu",
-    "No files or folders have been deleted yet" : "Oraindik ez da ezabatu fitxategirik edo karpetarik"
+    "No files or folders have been deleted yet" : "Oraindik ez da ezabatu fitxategirik edo karpetarik",
+    "You might not have have permissions to view it, ask the sender to share it" : "Baliteke hura ikusteko baimenik ez izatea; eskatu igorleari partekatzeko",
+    "Set up templates folder" : "Konfiguratu txantiloien karpeta",
+    "Toggle %1$s sublist" : "Txandakatu %1$sazpizerrenda",
+    "Toggle grid view" : "Txandakatu sareta ikuspegia",
+    "Shares" : "Partekatzeak",
+    "Shared with others" : "Besteekin partekatuta",
+    "Shared with you" : "Zurekin partekatuta",
+    "Deleted shares" : "Ezabatutako partekatzeak",
+    "Pending shares" : "Zain dauden partekatzeak",
+    "The files is locked" : "Fixategiak blokeatuta dago"
 },
 "nplurals=2; plural=(n != 1);");
