@@ -101,12 +101,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Boş depolama alanınız bitmek üzere ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["\"{filter}\" ile eşleşiyor","\"{filter}\" ile eşleşiyor"],
     "View in folder" : "Klasörde görüntüle",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Doğrudan bağlantı kopyalandı (yalnızca bu dosya ya da klasöre erişim izni olan kullanıcılar kullanabilir)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Doğrudan bağlantı kopyalandı (yalnızca bu dosya ya da klasöre erişim izni olan kişiler kullanabilir)",
     "Path" : "Yol",
     "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
     "Favorited" : "Sık kullanılanlara eklendi",
     "Favorite" : "Sık kullanılanlara ekle",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Doğrudan bağlantıyı kopyala (yalnızca bu dosya ya da klasöre erişim izni olan kullanıcılar için)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Doğrudan bağlantıyı kopyala (yalnızca bu dosya ya da klasöre erişim izni olan kişiler için)",
     "New folder" : "Yeni klasör",
     "Create new folder" : "Klasör ekle",
     "Upload file" : "Dosya yükle",
@@ -127,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "{user} tarafından geri yüklendi",
     "Renamed by {user}" : "{user} tarafından adı değiştirildi",
     "Moved by {user}" : "{user} tarafından taşındı",
-    "\"remote user\"" : "\"uzak kullanıcı\"",
+    "\"remote account\"" : "\"uzak hesap\"",
     "You created {file}" : "{file} dosyasını eklediniz",
     "You created an encrypted file in {file}" : "{file} içinde şifrelenmiş bir dosya oluşturdunuz",
     "{user} created {file}" : "{user}, {file} dosyasını ekledi",
@@ -175,16 +175,16 @@ OC.L10N.register(
     "Drag and drop files here to upload" : "Yüklemek istediğiniz dosyaları sürükleyip buraya bırakın",
     "Your have used your space quota and cannot upload files anymore" : "Depolama alanınızın tümünü kullandığınız için başka dosya yüklemezsiniz",
     "You don’t have permission to upload or create files here" : "Buraya dosya yükleme ya da ekleme izniniz yok",
-    "Upload successful" : "Yüklendi",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" işlemi tamamlandı",
     "\"{displayName}\" action failed" : "\"{displayName}\" işlemi tamamlanamadı",
-    "Toggle selection for file \"{displayName}\"" : "\"{displayName}\" dosyasının seçimini değiştir",
-    "Toggle selection for folder \"{displayName}\"" : "\"{displayName}\" klasörünün seçimini değiştir",
+    "Toggle selection for file \"{displayName}\"" : "\"{displayName}\" dosyasını seç/bırak",
+    "Toggle selection for folder \"{displayName}\"" : "\"{displayName}\" klasörünü seç/bırak",
     "Rename file" : "Dosyayı yeniden adlandır",
     "File name" : "Dosya adı",
     "Folder name" : "Klasör adı",
     "This node is unavailable" : "Bu düğüm kullanılamıyor",
     "Download file {name}" : "{name} dosyasını indir",
+    "Invalid file name" : "Dosya adı geçersiz",
     "\"{name}\" is not an allowed filetype." : "\"{name}\" dosya türüne izin verilmiyor.",
     "{newName} already exists." : "{newName} zaten var.",
     "\"{char}\" is not allowed inside a file name." : "Dosya adlarında \"{char}\" karakteri kullanılamaz.",
@@ -194,12 +194,11 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" adı artık olmadığından değiştirilemedi. ",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" adı \"{dir}\" klasöründe zaten kullanılmış. Lütfen başka bir ad seçin.",
     "Could not rename \"{oldName}\"" : "\"{oldName}\" adı değiştirilemedi",
-    "Could not copy {file}. {message}" : "{file} dosyası kopyalanamadı. {message}",
-    "Could not move {file}. {message}" : "{file} dosyası taşınamadı. {message}",
     "Total rows summary" : "Toplam satır özeti",
-    "Toggle selection for all files and folders" : "Tüm dosya ve klasörlerin seçimini değiştir",
+    "Toggle selection for all files and folders" : "Tüm dosyaları ve klasörleri seç/bırak",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" toplu işlemi bazı bileşenlerde tamamlanamadı",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" toplu işlemi tamamlandı",
+    "{count} selected" : "{count} seçilmiş",
     "List of files and folders." : "Dosya ve klasörlerin listesi.",
     "Column headers with buttons are sortable." : "Düğmeler olan sütunlar sıralanabilir.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Başarımı olumsuz etkilememek için listenin tümü görüntülenmiyor. Listede ilerledikçe dosyalar görüntülenecek.",
@@ -209,6 +208,8 @@ OC.L10N.register(
     "{relative}% used" : "%{relative} kullanılmış",
     "Could not refresh storage stats" : "Depolama istatistikleri yenilenemedi",
     "Your storage is full, files can not be updated or synced anymore!" : "Boş depolama alanınız kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
+    "Create" : "Ekle",
+    "A file or folder with that name already exists." : "Aynı adlı bir dosya ya da klasör zaten var.",
     "Transfer ownership of a file or folder" : "Bir dosya ya da klasörün sahipliğini aktarabilirsiniz",
     "Choose file or folder to transfer" : "Sahipliği aktarılacak dosya ya da klasörü seçin",
     "Change" : "Değiştir",
@@ -223,7 +224,6 @@ OC.L10N.register(
     "Select file or folder to link to" : "Bağlantı verilecek dosya ya da klasörü seçin",
     "Choose file" : "Dosya seçin",
     "Choose {file}" : "{file} seçin",
-    "Add" : "Ekle",
     "Loading current folder" : "Geçerli klasör yükleniyor",
     "No files in here" : "Burada herhangi bir dosya yok",
     "Upload some content or sync with your devices!" : "Bir şeyler yükleyin ya da aygıtlarınızla eşitleyin!",
@@ -240,7 +240,11 @@ OC.L10N.register(
     "Open the files app settings" : "Dosyalar uygulaması ayarlarını aç",
     "Files settings" : "Dosyalar ayarları",
     "File cannot be accessed" : "Dosyaya erişilemedi",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Dosya bulunamadı ya da görüntüleme izniniz olmayabilir. Gönderenden paylaşmasını isteyin",
+    "Your files" : "Dosyalarınız",
+    "Open in files" : "Dosyalar uygulamasında aç",
     "Sort favorites first" : "Sık kullanılanlar üstte sıralansın",
+    "Sort folders before files" : "Klasörler dosyaların üzerinde sıralansın",
     "Show hidden files" : "Gizli dosyaları görüntüle",
     "Crop image previews" : "Görsel ön izlemeleri kırpılsın",
     "Enable the grid view" : "Tablo görünümü kullanılsın",
@@ -255,33 +259,58 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
     "Error while loading the file data" : "Dosya verileri yüklenirken sorun çıktı",
     "Pick a template for {name}" : "{name} için bir kalıp seçin",
-    "Create" : "Ekle",
     "Create a new file with the selected template" : "Seçilmiş kalıp ile yeni bir dosya ekle",
     "Creating file" : "Dosya ekleniyor",
     "Blank" : "Boş",
     "Unable to create new file from template" : "Kalıptan yeni dosya eklenemedi",
     "Delete permanently" : "Kalıcı olarak sil",
+    "Delete and unshare" : "Sil ve paylaşımdan kaldır",
+    "Leave these shares" : "Bu paylaşımlardan ayrıl",
+    "Disconnect storages" : "Depolama alanlarının bağlantısını kes",
+    "Delete files" : "Dosyaları sil",
+    "Delete folders" : "Klasörleri sil",
+    "You are about to delete {count} items." : "{count} ögeyi silmek üzeresiniz.",
+    "Confirm deletion" : "Silmeyi onaylayın",
+    "Cancel" : "İptal",
+    "Deletion cancelled" : "Silme iptal edildi",
     "Destination is not a folder" : "Hedef bir klasör değil",
     "This file/folder is already in that directory" : "Dosya ya da klasör bu klasörde zaten var",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Bir dosyayı ya da klasörü kendi üzerine veya kendisinin alt klasörüne taşıyamazsınız",
     "(copy)" : "(kopya)",
     "(copy %n)" : "(%n kopyası)",
+    "Move cancelled" : "Taşıma iptal edildi",
     "A file or folder with that name already exists in this folder" : "Bu klasörde aynı adlı bir dosya ya da klasör zaten var",
-    "The files is locked" : "Dosyalar kilitli",
+    "The files are locked" : "Dosyalar kilitli",
     "The file does not exist anymore" : "Dosya artık yok",
     "Choose destination" : "Hedefi seçin",
     "Copy to {target}" : "{target} içine kopyala",
     "Move to {target}" : "{target} içine taşı",
     "Cancelled move or copy operation" : "Taşıma ya da kopyalama işlemi iptal edildi",
+    "Move or copy operation failed" : "Taşıma ya da kopyalama yapılamadı",
     "Open folder {displayName}" : "{displayName} klasörünü aç",
     "Open in Files" : "Dosyalar uygulamasında aç",
     "Open details" : "Ayrıntıları aç",
+    "Created new folder \"{name}\"" : "\"{name}\" yeni klasörü oluşturuldu",
+    "Filename" : "Dosya adı",
+    "Unable to initialize the templates directory" : "Kalıp klasörü hazırlanamadı",
     "Create new templates folder" : "Yeni kalıp klasörü oluştur",
     "Templates" : "Kalıplar",
-    "Unable to initialize the templates directory" : "Kalıp klasörü hazırlanamadı",
-    "Created new folder \"{name}\"" : "\"{name}\" yeni klasörü oluşturuldu",
+    "New template folder" : "Yeni kalıp klasörü",
+    "In folder" : "Klasörde",
+    "Search in folder: {folder}" : "Şu klasörde ara: {folder}",
     "One of the dropped files could not be processed" : "Bırakılan dosyalardan biri işlenemedi",
-    "Uploading \"{filename}\" failed" : "\"{filename}\" yüklenemedi",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Tarayıcınız dosya sistemi API uygulamasını desteklemiyor. Klasörler yüklenemeyecek",
+    "No files to upload" : "Yüklenecek bir dosya yok",
+    "Unable to create the directory {directory}" : "{directory} klasörü oluşturulamadı",
+    "Some files could not be uploaded" : "Bazı dosyalar yüklenemedi",
+    "Files uploaded successfully" : "Dosyalar yüklendi",
+    "No files to process" : "İşlenecek bir dosya yok",
+    "Some files could not be copied" : "Bazı dosyalar kopyalanamadı",
+    "Some files could not be moved" : "Bazı dosyalar taşınamadı",
+    "Files copied successfully" : "Dosyalar kopyalandı",
+    "Files moved successfully" : "Dosyalar taşındı",
+    "Conflicts resolution skipped" : "Çakışma çözümleme atlandı",
+    "Upload cancelled" : "Yükleme iptal edildi",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} klasör","{folderCount} klasör"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} dosya","{fileCount} dosya"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 dosya ve {folderCount} klasör","1 dosya ve {folderCount} klasör"],
@@ -292,6 +321,10 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Sık kullanılanlara eklediğiniz dosya ve klasörler burada görüntülenir",
     "All files" : "Tüm dosyalar",
     "List of your files and folders." : "Dosya ve klasörlerinizin listesi",
+    "Personal Files" : "Kişisel dosyalar",
+    "List of your files and folders that are not shared." : "Paylaşılmayan dosya ve klasörlerinizin listesi.",
+    "No personal files found" : "Herhangi bir kişisel dosya bulunamadı",
+    "Files that are not shared will show up here." : "Paylaşımayan dosyalar burada görüntülenir.",
     "List of recently modified files and folders." : "Son değiştirilen dosya ve klasörlerin listesi.",
     "No recently modified files" : "Yakınlarda değiştirilmiş bir dosya yok",
     "Files and folders you recently modified will show up here." : "Son zamanlarda değiştirdiğiniz dosya ve klasörler burada görüntülenir.",
@@ -301,21 +334,12 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucuya yüklenmesine izin verilen en büyük dosya boyutunu aşıyor.",
     "Text file" : "Metin dosyası",
     "New text file.txt" : "Yeni metin dosyası.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Doğrudan bağlantı kopyalandı (yalnızca bu dosya ya da klasöre erişim izni olan kullanıcılar kullanabilir)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Doğrudan bağlantıyı kopyala (yalnızca bu dosya ya da klasöre erişim izni olan kullanıcılar için)",
     "You can only favorite a single file or folder at a time" : "Aynı anda yalnızca bir dosya ya da bir klasör sık kullanılanlara eklenebilir",
-    "Search users" : "Kullanıcı arama",
-    "You might not have have permissions to view it, ask the sender to share it" : "Dosyayı görüntüleme izniniz olmayabilir. Gönderenden paylaşmasını isteyin",
-    "Cancel" : "İptal",
-    "Set up templates folder" : "Kalıp klasörünü ayarlayın",
-    "Toggle %1$s sublist" : "%1$s alt listesini aç/kapat",
-    "Toggle grid view" : "Tablo görünümünü değiştir",
-    "Deleted files" : "Silinmiş dosyalar",
-    "Shares" : "Paylaşımlar",
-    "Shared with others" : "Başkalarıyla paylaşılan",
-    "Shared with you" : "Sizinle paylaşılan",
-    "Deleted shares" : "Silinmiş paylaşımlar",
-    "Pending shares" : "Bekleyen paylaşımlar",
     "This file has the tag {tag}" : "Dosya {tag} olarak etiketlenmiş",
     "This file has the tags {firstTags} and {lastTag}" : "Dosya {firstTags} ve {lastTag} olarak etiketlenmiş",
+    "\"remote user\"" : "\"uzak kullanıcı\"",
     "Select the row for {displayName}" : "{displayName} satırını seç",
     "Open folder {name}" : "{name} klasörünü aç",
     "Unselect all" : "Tümünü bırak",
@@ -325,6 +349,16 @@ OC.L10N.register(
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Başarımı olumsuz etkilememek için listenin tümü görüntülenmiyor. Listede ilerledikçe dosyalar görüntülenecek.",
     "Search for an account" : "Hesap ara",
     "Choose" : "Seçin",
-    "No files or folders have been deleted yet" : "Henüz silinmiş bir dosya ya da klasör yok"
+    "No files or folders have been deleted yet" : "Henüz silinmiş bir dosya ya da klasör yok",
+    "You might not have have permissions to view it, ask the sender to share it" : "Dosyayı görüntüleme izniniz olmayabilir. Gönderenden paylaşmasını isteyin",
+    "Set up templates folder" : "Kalıp klasörünü ayarlayın",
+    "Toggle %1$s sublist" : "%1$s alt listesini aç/kapat",
+    "Toggle grid view" : "Tablo görünümünü aç/kapat",
+    "Shares" : "Paylaşımlar",
+    "Shared with others" : "Başkalarıyla paylaşılan",
+    "Shared with you" : "Sizinle paylaşılan",
+    "Deleted shares" : "Silinmiş paylaşımlar",
+    "Pending shares" : "Bekleyen paylaşımlar",
+    "The files is locked" : "Dosyalar kilitli"
 },
 "nplurals=2; plural=(n > 1);");
