@@ -35,9 +35,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Поддържани са следните платформи: %s",
     "Server version %s or higher is required." : "Нужна е версия на сървъра %s или по-нова.",
     "Server version %s or lower is required." : "Нужна е версия на сървъра %s или по-ниска.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Влезлият потребител трябва да е администратор, подадминистратор или да е получил специално право за достъп до тази настройка",
-    "Logged in user must be an admin or sub admin" : "Влезлият потребител трябва да е администратор или подадминистратор ",
-    "Logged in user must be an admin" : "Влезлият потребител трябва да е администратор",
     "Wiping of device %s has started" : "Започна изтриването на устройството %s",
     "Wiping of device »%s« has started" : "»%s« Започна изтриването на устройството ",
     "»%s« started remote wipe" : "»%s« започна отдалечено изтриване",
@@ -91,7 +88,6 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Приложението \"%s\" не може да бъде инсталирано, защото не е съвместимо с тази версия на сървъра.",
     "__language_name__" : "Български",
     "This is an automatically sent email, please do not reply." : "Имейлът е генериран автоматично, моля не отговаряйте.",
-    "Help" : "Помощ",
     "Appearance and accessibility" : "Изглед и достъпност",
     "Apps" : "Приложения",
     "Personal settings" : "Лични настройки",
@@ -116,22 +112,15 @@ OC.L10N.register(
     "Headline" : "Заглавие",
     "Organisation" : "Организация",
     "Role" : "Роля",
-    "Unknown user" : "Непознат потребител",
     "Additional settings" : "Допълнителни настройки",
-    "Enter the database username and name for %s" : "Въведете името на потребител на базата данни и име за %s",
-    "Enter the database username for %s" : "Въведете името на потребител на базата данни за %s",
     "Enter the database name for %s" : "Въведете името на базата данни за %s",
     "You cannot use dots in the database name %s" : "Не можете да използвате точки в името на базата данни %s",
-    "MySQL username and/or password not valid" : "Име на потребител и/или паролата на MySQL не са валидни",
     "You need to enter details of an existing account." : "Трябва да въведете подробности за съществуващ профил.",
     "Oracle connection could not be established" : "Не можа да се установи връзка с Oracle",
-    "Oracle username and/or password not valid" : "Невалидно Oracle потребителско име и/или парола.",
-    "PostgreSQL username and/or password not valid" : "Невалидно PostgreSQL потребителско име и/или парола.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не се подържа и %s няма да работи правилно на тази платформа. Използвайте го на свой собствен риск!",
     "For the best results, please consider using a GNU/Linux server instead." : "За най-добри резултати, моля, помисли дали не бихте желали да използваште GNU/Linux сървър.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : " Изглежда, че този екземпляр %s работи в 32-битова PHP среда и open_basedir е конфигуриран в php.ini. Това ще доведе до проблеми с файлове над 4 GB и е силно обезкуражено.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Моля, премахтене настройката за open_basedir от вашия php.ini или преминете към 64-битово PHP.",
-    "Set an admin username." : "Задайте потребителско име за администратор.",
     "Set an admin password." : "Задай парола за администратор.",
     "Cannot create or write into the data directory %s" : "Неуспешно създаване или записване в директорията  с данни \"data\" %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Споделянето на сървърния %s трябва да поддържа OCP\\Share_Backend интерфейс.",
@@ -149,7 +138,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Срокът на валидност е изтекъл",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Не може да се зададе срок на валидност повече от %n дни в бъдещето","Не може да се зададе срок на валидност повече от %n дни в бъдещето"],
     "Sharing is only allowed with group members" : "Споделянето е разрешено само с членове на групата",
-    "Sharing %s failed, because this item is already shared with user %s" : "Неуспешно споделяне на %s, защото този елемент вече е споделен с потребителя %s",
     "%1$s shared »%2$s« with you" : "%1$s сподели »%2$s« с вас",
     "%1$s shared »%2$s« with you." : "%1$s сподели »%2$s« с вас.",
     "Click the button below to open it." : "Щракнете върху бутона по-долу, за да го отворите.",
@@ -202,14 +190,6 @@ OC.L10N.register(
     "Nov." : "ное",
     "Dec." : "дек",
     "A valid password must be provided" : "Трябва да въведете валидна парола.",
-    "The username is already being used" : "Потребителското име е вече заето.",
-    "Could not create user" : "Неуспешно създаване на потребител",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Потребителските имена може да съдържат само следните знаци: \"a-z\", \"A-Z\", \"0-9\" и \"_.@-'\"",
-    "A valid username must be provided" : "Трябва да въведете валидно потребителско.",
-    "Username contains whitespace at the beginning or at the end" : "Потребителското име започва или завършва с интервал.",
-    "Username must not consist of dots only" : "Името на потребител не трябва да се състои само от точки",
-    "Username is invalid because files already exist for this user" : "Името на потребител е невалидно, тъй като файловете вече съществуват за този потребител",
-    "User disabled" : "Потребителят е деактивиран",
     "Login canceled by app" : "Вписването е отказано от приложението",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Приложението „%1$s“ не може да бъде инсталирано, защото следните зависимости не са изпълнени: %2$s",
     "a safe home for all your data" : "безопасен дом за всички ваши данни",
@@ -242,8 +222,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Моля, поискай от своя администратор да рестартира уеб сървъра.",
     "The required %s config variable is not configured in the config.php file." : "Необходимата %s конфигурационна променлива не е конфигурирана във файла config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Моля, помолете администратора на вашия сървър да провери конфигурацията на Nextcloud.",
-    "Your data directory is readable by other users." : "Вашата директория с данни може да се чете от други потребители.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Моля, променете правата за достъп на 0770, за да не може директорията да бъде видяна от други потребители.",
     "Your data directory must be an absolute path." : "Вашата директория с данни трябва да е абсолютен път.",
     "Check the value of \"datadirectory\" in your configuration." : "Проверете стойността на \"datadirectory\" във вашата конфигурация.",
     "Your data directory is invalid." : "Вашата директория с данни е невалидна.",
@@ -259,12 +237,30 @@ OC.L10N.register(
     "Storage connection error. %s" : "Грешка при свързването с хранилище. %s",
     "Storage is temporarily not available" : "Временно хранилището не е налично",
     "Storage connection timeout. %s" : "Време за изчакване при свързването с хранилище. %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Файловете на приложението %1$s не бяха заменени правилно. Уверете се, че версията е съвместима със сървъра.",
     "404" : "404",
-    "Full name" : "Пълно име",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Нужно е поне libxml2 2.7.0. В момента са инсталирани %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "За да отстраните този проблем, актуализирайте версията на libxml2 и рестартирайте вашия уеб сървър.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Влезлият потребител трябва да е администратор, подадминистратор или да е получил специално право за достъп до тази настройка",
+    "Logged in user must be an admin or sub admin" : "Влезлият потребител трябва да е администратор или подадминистратор ",
+    "Logged in user must be an admin" : "Влезлият потребител трябва да е администратор",
+    "Help" : "Помощ",
+    "Unknown user" : "Непознат потребител",
+    "Enter the database username and name for %s" : "Въведете името на потребител на базата данни и име за %s",
+    "Enter the database username for %s" : "Въведете името на потребител на базата данни за %s",
+    "MySQL username and/or password not valid" : "Име на потребител и/или паролата на MySQL не са валидни",
+    "Oracle username and/or password not valid" : "Невалидно Oracle потребителско име и/или парола.",
+    "PostgreSQL username and/or password not valid" : "Невалидно PostgreSQL потребителско име и/или парола.",
+    "Set an admin username." : "Задайте потребителско име за администратор.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Неуспешно споделяне на %s, защото този елемент вече е споделен с потребителя %s",
+    "The username is already being used" : "Потребителското име е вече заето.",
+    "Could not create user" : "Неуспешно създаване на потребител",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Потребителските имена може да съдържат само следните знаци: \"a-z\", \"A-Z\", \"0-9\" и \"_.@-'\"",
+    "A valid username must be provided" : "Трябва да въведете валидно потребителско.",
+    "Username contains whitespace at the beginning or at the end" : "Потребителското име започва или завършва с интервал.",
+    "Username must not consist of dots only" : "Името на потребител не трябва да се състои само от точки",
+    "Username is invalid because files already exist for this user" : "Името на потребител е невалидно, тъй като файловете вече съществуват за този потребител",
+    "User disabled" : "Потребителят е деактивиран",
     "PostgreSQL >= 9 required." : "Нужно е PostgreSQL >= 9",
-    "Please upgrade your database version." : "Моля, надстройте версията на вашата база данни."
+    "Please upgrade your database version." : "Моля, надстройте версията на вашата база данни.",
+    "Your data directory is readable by other users." : "Вашата директория с данни може да се чете от други потребители.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Моля, променете правата за достъп на 0770, за да не може директорията да бъде видяна от други потребители."
 },
 "nplurals=2; plural=(n != 1);");
