@@ -8,7 +8,6 @@ OC.L10N.register(
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "A aplicación %1$s non está presente ou ten unha versión non compatíbel con este servidor. Comprobe o directorio de aplicacións.",
     "Sample configuration detected" : "Detectouse a configuración de exemplo",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detectouse que foi copiada a configuración de exemplo. Isto pode rachar a súa instalación e non é compatíbel. Lea a documentación antes de facer cambios en config.php",
-    "404" : "404",
     "The page could not be found on the server." : "Non foi posíbel atopar a páxina no servidor.",
     "%s email verification" : "Verificación do correo-e %s",
     "Email verification" : "Verificación do correo-e",
@@ -24,22 +23,23 @@ OC.L10N.register(
     "Enterprise bundle" : "Paquete empresarial",
     "Groupware bundle" : "Paquete de software colaborativo",
     "Hub bundle" : "Paquete de concentradores",
+    "Public sector bundle" : "Paquete do sector público",
     "Social sharing bundle" : "Paquete para compartir en redes sociais",
-    "PHP %s or higher is required." : "Precisase PHP %s ou superior.",
-    "PHP with a version lower than %s is required." : "Precisase PHP cunha versión inferior a %s.",
-    "%sbit or higher PHP required." : "Precisase PHP para %sbits ou superior.",
+    "PHP %s or higher is required." : "Precísase de PHP %s ou superior.",
+    "PHP with a version lower than %s is required." : "Precísase de PHP cunha versión inferior a %s.",
+    "%sbit or higher PHP required." : "Precísase de PHP para %s bits ou superior.",
     "The following architectures are supported: %s" : "Admítense as seguintes arquitecturas: %s",
     "The following databases are supported: %s" : "Admítense as seguintes bases de datos: %s",
     "The command line tool %s could not be found" : "Non foi posíbel atopar a ferramenta de liña de ordes %s",
     "The library %s is not available." : "Non está dispoñíbel a biblioteca %s.",
-    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Precisase a biblioteca %1$s cunha versión superior a %2$s - dispoñíbel a versión %3$s.",
-    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Precisase a biblioteca %1$s cunha versión inferior a %2$s - dispoñíbel a versión %3$s.",
+    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Precísase da biblioteca %1$s cunha versión superior a %2$s - dispoñíbel a versión %3$s.",
+    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Precísase da biblioteca %1$s cunha versión inferior a %2$s - dispoñíbel a versión %3$s.",
     "The following platforms are supported: %s" : "Admítense as seguintes plataformas: %s",
-    "Server version %s or higher is required." : "Precisase a versión %s ou superior do servidor.",
-    "Server version %s or lower is required." : "Precisase a versión %s ou inferior do servidor.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuario que accede debe ser un administrador, un subadministrador ou ter un dereito especial para acceder a esta configuración",
-    "Logged in user must be an admin or sub admin" : "O usuario autenticado debe ser un administrador ou subadministrador",
-    "Logged in user must be an admin" : "O usuario conectado debe ser un administrador",
+    "Server version %s or higher is required." : "Precísase da versión %s ou superior do servidor.",
+    "Server version %s or lower is required." : "Precísase da versión %s ou inferior do servidor.",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "A conta iniciada debe ser un administrador, un subadministrador ou ter un dereito especial para acceder a esta opción",
+    "Logged in account must be an admin or sub admin" : "A conta iniciada debe ser administrador ou subadministrador",
+    "Logged in account must be an admin" : "A conta iniciada debe ser un administrador",
     "Wiping of device %s has started" : "Iniciouse a limpeza do dispositivo %s",
     "Wiping of device »%s« has started" : "Iniciouse a limpeza do dispositivo «%s»",
     "»%s« started remote wipe" : "«%s» iniciou a limpeza remota",
@@ -63,19 +63,19 @@ OC.L10N.register(
     "tomorrow" : "mañá",
     "yesterday" : "onte",
     "_in %n day_::_in %n days_" : ["en %n día","en %n días"],
-    "_%n day ago_::_%n days ago_" : ["hai %n día","hai %n días"],
+    "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n días"],
     "next month" : "o vindeiro mes",
     "last month" : "o mes pasado",
     "_in %n month_::_in %n months_" : ["en %n mes","en %n meses"],
-    "_%n month ago_::_%n months ago_" : ["hai %n mes","hai %n meses"],
+    "_%n month ago_::_%n months ago_" : ["Hai %n mes","Hai %n meses"],
     "next year" : "o vindeiro ano",
     "last year" : "o ano pasado",
     "_in %n year_::_in %n years_" : ["en %n ano","en %n anos"],
-    "_%n year ago_::_%n years ago_" : ["hai %n ano","hai %n anos"],
+    "_%n year ago_::_%n years ago_" : ["Hai %n ano","Hai %n anos"],
     "_in %n hour_::_in %n hours_" : ["en %n hora","en %n horas"],
-    "_%n hour ago_::_%n hours ago_" : ["hai %n hora","hai %n horas"],
+    "_%n hour ago_::_%n hours ago_" : ["Hai %n hora","Hai %n horas"],
     "_in %n minute_::_in %n minutes_" : ["en %n minuto","en %n minutos"],
-    "_%n minute ago_::_%n minutes ago_" : ["hai %n minuto","hai %n minutos"],
+    "_%n minute ago_::_%n minutes ago_" : ["Hai %n minuto","Hai %n minutos"],
     "in a few seconds" : "en poucos segundos",
     "seconds ago" : "segundos atrás",
     "Empty file" : "Ficheiro baleiro",
@@ -93,7 +93,6 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Non é posíbel instalar a aplicación «%s» por mor de non ser compatíbel con esta versión do servidor.",
     "__language_name__" : "Galego",
     "This is an automatically sent email, please do not reply." : "Este é un correo enviado automaticamente, non responda.",
-    "Help" : "Axuda",
     "Appearance and accessibility" : "Aspecto e accesibilidade",
     "Apps" : "Aplicacións",
     "Personal settings" : "Axustes persoais",
@@ -118,22 +117,22 @@ OC.L10N.register(
     "Headline" : "Titular",
     "Organisation" : "Organización",
     "Role" : "Cargo",
-    "Unknown user" : "Usuario descoñecido",
+    "Unknown account" : "Conta descoñecida",
     "Additional settings" : "Axustes adicionais",
-    "Enter the database username and name for %s" : "Introduza o nome de usuario da ase de datos e o nome para %s",
-    "Enter the database username for %s" : "Introduza o nome de usuario da base de datos para %s",
+    "Enter the database Login and name for %s" : "Introduza o inicio de sesión e o nome da base de datos para %s",
+    "Enter the database Login for %s" : "Introduza a base de datos Iniciar sesión para %s",
     "Enter the database name for %s" : "Introduza o nome da base de datos para %s",
     "You cannot use dots in the database name %s" : "Non pode usar puntos no nome da base de datos %s",
-    "MySQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de MySQL incorrecto",
+    "MySQL Login and/or password not valid" : "O inicio de sesión de MySQL e/ou o contrasinal non son válidos",
     "You need to enter details of an existing account." : "Debe introducir os detalles dunha conta existente.",
     "Oracle connection could not be established" : "Non foi posíbel estabelecer a conexión con Oracle",
-    "Oracle username and/or password not valid" : "O nome de usuario e/ou contrasinal de Oracle é incorrecto",
-    "PostgreSQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de PostgreSQL incorrecto",
+    "Oracle Login and/or password not valid" : "O inicio de sesión ou contrasinal de Oracle non é válido",
+    "PostgreSQL Login and/or password not valid" : "O inicio de sesión e/ou o contrasinal de PostgreSQL non son válidos",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X non é compatíbel e %s non funcionará correctamente nesta plataforma. Utilíceo baixo a  súa responsabilidade!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter mellores resultados, considere o emprego dun servidor GNU/Linux no seu canto.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Semella que esta instancia de %s está a funcionar nun contorno PHP de 32 bisst e o open_basedir foi configurado no php.ini. Isto provocará problemas con ficheiros maiores de 4 GB e está absolutamente desaconsellado.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Retire o axuste de open_basedir no php.ini ou cambie a PHP de 64 bits.",
-    "Set an admin username." : "Estabeleza un nome de usuario administrador",
+    "Set an admin Login." : "Establece un inicio de sesión de administrador.",
     "Set an admin password." : "Estabeleza un contrasinal de administrador",
     "Cannot create or write into the data directory %s" : "Non é posíbel crear ou escribir no directorio de datos %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A infraestrutura de compartición %s ten que implementar a interface OCP\\Share_Backend",
@@ -151,11 +150,12 @@ OC.L10N.register(
     "Expiration date is in the past" : "Xa pasou a data de caducidade",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Non é posíbel estabelecer a data de caducidade máis alo de %n día no futuro","Non é posíbel estabelecer a data de caducidade máis alo de %n días no futuro"],
     "Sharing is only allowed with group members" : "Só se permite compartir cos membros do grupo",
-    "Sharing %s failed, because this item is already shared with user %s" : "Fallou a compartición de %s por mor de que este elemento xa foi compartido co usuario %s",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Produciuse un erro ao compartir %s, porque este elemento xa se comparte coa conta %s",
     "%1$s shared »%2$s« with you" : "%1$s compartiu «%2$s» con Vde.",
     "%1$s shared »%2$s« with you." : "%1$s compartiu «%2$s» con Vde.",
     "Click the button below to open it." : "Prema no botón de embaixo para abrilo.",
     "The requested share does not exist anymore" : "A compartición solicitada xa non existe",
+    "The requested share comes from a disabled user" : "A compartición solicitada procede dun usuario desactivado",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Non se creou o usuario porque acadouse o límite de usuarios. Consulte as súas notificacións para obter máis información.",
     "Could not find category \"%s\"" : "Non foi posíbel atopar a categoría «%s»",
     "Sunday" : "domingo",
@@ -204,17 +204,17 @@ OC.L10N.register(
     "Nov." : "nov.",
     "Dec." : "dec.",
     "A valid password must be provided" : "Debe fornecer un contrasinal",
-    "The username is already being used" : "Este nome de usuario xa está a ser usado",
-    "Could not create user" : "Non foi posíbel crear o usuario",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Só se permiten os seguintes caracteres nun nome de usuario: «a-z», «A-Z», «0-9», espazos e «_.@-'»",
-    "A valid username must be provided" : "Debe fornecer un nome de usuario correcto",
-    "Username contains whitespace at the beginning or at the end" : "O nome de usuario contén un espazo en branco no inicio ou no final",
-    "Username must not consist of dots only" : "O nome de usuario non debe consistir só de puntos",
-    "Username is invalid because files already exist for this user" : "O nome de usuario non é válido porque xa existen ficheiros para este usuario",
-    "User disabled" : "Usuario desactivado",
+    "The Login is already being used" : "O inicio de sesión xa se está a usar",
+    "Could not create account" : "Non se puido crear a conta",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Só se permiten os seguintes caracteres nun inicio de sesión: \"a-z\", \"A-Z\", \"0-9\", espazos e \"_.@-'\"",
+    "A valid Login must be provided" : "É necesario proporcionar un inicio de sesión válido",
+    "Login contains whitespace at the beginning or at the end" : "O inicio de sesión contén espazos en branco ao comezo ou ao final",
+    "Login must not consist of dots only" : "O inicio de sesión non debe estar composto só por puntos",
+    "Login is invalid because files already exist for this user" : "O inicio de sesión non é válido porque xa existen ficheiros para este usuario",
+    "Account disabled" : "Conta deshabilitada",
     "Login canceled by app" : "Acceso cancelado pola aplicación",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Non é posíbel instalar a aplicación «%1$s» por mor de non cumprirse as dependencias: %2$s",
-    "a safe home for all your data" : "un lugar seguro para todos os seus datos",
+    "a safe home for all your data" : "un acubillo seguro para todos os seus datos",
     "File is currently busy, please try again later" : "O ficheiro está ocupado neste momento, ténteo máis adiante.",
     "Cannot download file" : "Non é posíbel descargar o ficheiro",
     "Application is not enabled" : "A aplicación non está activada",
@@ -242,12 +242,10 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto probabelmente se debe unha caché/acelerador como Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse os módulos de PHP, mais aínda aparecen listados como perdidos?",
     "Please ask your server administrator to restart the web server." : "Pídalle á administración do seu servidor que reinicie o servidor web.",
-    "The required %s config variable is not configured in the config.php file." : "Precísase a variábel de configuración %s e non está configurada no ficheiro config.php.",
+    "The required %s config variable is not configured in the config.php file." : "Precísase da variábel de configuración %s e non está configurada no ficheiro config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Pídalle á administración do seu servidor que verifique a configuración de Nextcloud.",
-    "PostgreSQL >= 9 required." : "Precisase PostgreSQL >= 9.",
-    "Please upgrade your database version." : "Anove a versión da súa base de datos",
-    "Your data directory is readable by other users." : "Outros usuarios poden leer o seu directorio de datos.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambie os permisos a 0770 para que o directorio non poida ser listado por outros usuarios.",
+    "Your data directory is readable by other people." : "Outras persoas poden ler o teu directorio de datos.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Por favor, cambie os permisos a 0770 para que o directorio non poida ser listado por outras persoas.",
     "Your data directory must be an absolute path." : "O seu directorio de datos debe ser unha ruta absoluta.",
     "Check the value of \"datadirectory\" in your configuration." : "Comprobe o valor de «datadirectory» na súa configuración-",
     "Your data directory is invalid." : "O seu directorio de datos non é válido.",
@@ -271,11 +269,30 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Resume o texto reducindo a súa lonxitude sen perder a información clave.",
     "Extract topics" : "Extraer temas",
     "Extracts topics from a text and outputs them separated by commas." : "Extrae temas dun texto e amósaos separados por comas.",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Os ficheiros da aplicación %1$s non foron substituídos correctamente. Asegúrese que é unha versión compatíbel co servidor.",
-    "Full name" : "Nome completo",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Acadouse o límite de usuarios e non se creou o usuario. Consulte as súas notificacións para obter máis información.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Só os seguintes caracteres están permitidos nos nomes de usuario: «a-z», «A-Z», «0-9» e «_.@-'»",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Precisase, cando menos, libxml2 2.7.0. Actualmente esta instalado %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Para arranxar esta incidencia, actualice a versión de libxml2 e reinicie o servidor web. "
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuario que accede debe ser un administrador, un subadministrador ou ter un dereito especial para acceder a esta configuración",
+    "Logged in user must be an admin or sub admin" : "O usuario autenticado debe ser un administrador ou subadministrador",
+    "Logged in user must be an admin" : "O usuario conectado debe ser un administrador",
+    "Help" : "Axuda",
+    "Unknown user" : "Usuario descoñecido",
+    "Enter the database username and name for %s" : "Introduza o nome de usuario da ase de datos e o nome para %s",
+    "Enter the database username for %s" : "Introduza o nome de usuario da base de datos para %s",
+    "MySQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de MySQL incorrecto",
+    "Oracle username and/or password not valid" : "O nome de usuario e/ou contrasinal de Oracle é incorrecto",
+    "PostgreSQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de PostgreSQL incorrecto",
+    "Set an admin username." : "Estabeleza un nome de usuario administrador",
+    "Sharing %s failed, because this item is already shared with user %s" : "Fallou a compartición de %s por mor de que este elemento xa foi compartido co usuario %s",
+    "The username is already being used" : "Este nome de usuario xa está a ser usado",
+    "Could not create user" : "Non foi posíbel crear o usuario",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Só se permiten os seguintes caracteres nun nome de usuario: «a-z», «A-Z», «0-9», espazos e «_.@-'»",
+    "A valid username must be provided" : "Debe fornecer un nome de usuario correcto",
+    "Username contains whitespace at the beginning or at the end" : "O nome de usuario contén un espazo en branco no inicio ou no final",
+    "Username must not consist of dots only" : "O nome de usuario non debe consistir só de puntos",
+    "Username is invalid because files already exist for this user" : "O nome de usuario non é válido porque xa existen ficheiros para este usuario",
+    "User disabled" : "Usuario desactivado",
+    "PostgreSQL >= 9 required." : "Precísase de PostgreSQL >= 9.",
+    "Please upgrade your database version." : "Anove a versión da súa base de datos",
+    "Your data directory is readable by other users." : "Outros usuarios poden leer o seu directorio de datos.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambie os permisos a 0770 para que o directorio non poida ser listado por outros usuarios."
 },
 "nplurals=2; plural=(n != 1);");
