@@ -8,7 +8,6 @@ OC.L10N.register(
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Aplicação %1$s não está presente ou possui uma versão não compatível com este servidor. Verifique o diretório de aplicativos.",
     "Sample configuration detected" : "Configuração de exemplo detectada",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detectado que a configuração de exemplo foi copiada. Isso pode terminar sua instalação e não é suportado. Por favor leia a documentação antes de realizar mudanças no config.php",
-    "404" : "404",
     "The page could not be found on the server." : "A página não pôde ser encontrada no servidor.",
     "%s email verification" : "%s e-mail de verificação",
     "Email verification" : "E-mail de verificação",
@@ -24,6 +23,7 @@ OC.L10N.register(
     "Enterprise bundle" : "Pacote Enterprise",
     "Groupware bundle" : "Pacote Groupware",
     "Hub bundle" : "Pacote de hub",
+    "Public sector bundle" : "Pacote do setor público",
     "Social sharing bundle" : "Pacote de compartilhamento social",
     "PHP %s or higher is required." : "PHP %s ou superior é necessário.",
     "PHP with a version lower than %s is required." : "É necessária uma versão PHP mais antiga que a %s.",
@@ -37,9 +37,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "As seguintes plataformas são suportadas: %s",
     "Server version %s or higher is required." : "É requerido um servidor da versão %s ou superior.",
     "Server version %s or lower is required." : "É requerido um servidor da versão %s ou abaixo.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuário conectado deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
-    "Logged in user must be an admin or sub admin" : "O usuário conectado deve ser um administrador ou subadministrador",
-    "Logged in user must be an admin" : "O usuário conectado deve ser um administrador",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "A conta conectada deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
+    "Logged in account must be an admin or sub admin" : "A conta conectada deve ser de um administrador ou subadministrador",
+    "Logged in account must be an admin" : "A conta logada deve ser de um administrador",
     "Wiping of device %s has started" : "Limpeza do dispositivo %s iniciou",
     "Wiping of device »%s« has started" : "A limpeza do dispositivo »%s« terminou",
     "»%s« started remote wipe" : "»%s« iniciou a limpeza remota",
@@ -93,7 +93,6 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "O aplicativo \"%s\" não pode ser instalado pois não é compatível com a versão do servidor.",
     "__language_name__" : "Português Brasileiro",
     "This is an automatically sent email, please do not reply." : "Este e-mail é enviado automaticamente. Por favor, não responda.",
-    "Help" : "Ajuda",
     "Appearance and accessibility" : "Aparência e acessibilidade",
     "Apps" : "Aplicativos",
     "Personal settings" : "Configurações pessoais",
@@ -118,22 +117,22 @@ OC.L10N.register(
     "Headline" : "Título ",
     "Organisation" : "Organização",
     "Role" : "Função",
-    "Unknown user" : "Usuário desconhecido",
+    "Unknown account" : "Conta desconhecida",
     "Additional settings" : "Configurações adicionais",
-    "Enter the database username and name for %s" : "Digite o nome de usuário e o nome do banco de dados para %s",
-    "Enter the database username for %s" : "Digite o nome de usuário do banco de dados para %s",
+    "Enter the database Login and name for %s" : "Insira o login e o nome do banco de dados para %s",
+    "Enter the database Login for %s" : "Insira o login do banco de dados para %s",
     "Enter the database name for %s" : "Digite o nome do banco de dados para %s",
     "You cannot use dots in the database name %s" : "Você não pode usar pontos no nome do banco de dados %s",
-    "MySQL username and/or password not valid" : "Nome de usuário e/ou senha do MySQL inválidos",
+    "MySQL Login and/or password not valid" : "Login e/ou senha do MySQL inválidos",
     "You need to enter details of an existing account." : "Você necessita entrar detalhes de uma conta existente.",
     "Oracle connection could not be established" : "Conexão Oracle não pôde ser estabelecida",
-    "Oracle username and/or password not valid" : "Nome de usuário e/ou senha Oracle inválidos",
-    "PostgreSQL username and/or password not valid" : "Nome de usuário e/ou senha PostgreSQL inválidos",
+    "Oracle Login and/or password not valid" : "Login e/ou senha Oracle inválidos",
+    "PostgreSQL Login and/or password not valid" : "Login e/ou senha do PostgreSQL inválidos",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X não é suportado e %s não funcionará corretamente nesta plataforma. Use-o por sua conta e risco!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter melhores resultados, por favor considere o uso de um servidor GNU/Linux em seu lugar.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Aparentemente a instância %s está rodando em um ambiente PHP de 32 bits e o open_basedir foi configurado no php.ini. Isto pode gerar problemas com arquivos maiores que 4GB e é altamente não recomendável.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a configuração de open_basedir de seu php.ini ou mude o PHP para 64bit.",
-    "Set an admin username." : "Defina um nome do usuário administrador.",
+    "Set an admin Login." : "Defina um login de administrador.",
     "Set an admin password." : "Defina uma senha para o administrador.",
     "Cannot create or write into the data directory %s" : "Não foi possível criar ou escrever no diretório de dados %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A plataforma de compartilhamento %s deve implementar a interface OCP\\Share_Backend",
@@ -151,11 +150,12 @@ OC.L10N.register(
     "Expiration date is in the past" : "Data de expiração está no passado",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro"],
     "Sharing is only allowed with group members" : "O compartilhamento só é permitido com membros do grupo ",
-    "Sharing %s failed, because this item is already shared with user %s" : "Compartilhamento %s falhou, porque este item já está compartilhado com o usuário %s",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Falha no compartilhamento %s porque este item já está compartilhado com a conta %s",
     "%1$s shared »%2$s« with you" : "%1$s compartilhou »%2$s« com você",
     "%1$s shared »%2$s« with you." : "%1$s compartilhou »%2$s« com você.",
     "Click the button below to open it." : "Clique no botão abaixo para abri-lo.",
     "The requested share does not exist anymore" : "O compartilhamento solicitado não existe mais",
+    "The requested share comes from a disabled user" : "O compartilhamento solicitado vem de um usuário desabilitado",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "O usuário não foi criado porque o limite de usuários foi atingido. Confira suas notificações para saber mais.",
     "Could not find category \"%s\"" : "Impossível localizar a categoria \"%s\"",
     "Sunday" : "Domingo",
@@ -204,14 +204,14 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Dez.",
     "A valid password must be provided" : "Uma senha válida deve ser fornecida",
-    "The username is already being used" : "Este nome de usuário já está em uso",
-    "Could not create user" : "Não foi possível criar o usuário",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Apenas os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", espaços e \"_.@-'\"",
-    "A valid username must be provided" : "Um nome de usuário válido deve ser fornecido",
-    "Username contains whitespace at the beginning or at the end" : "O nome de usuário contém espaço em branco no início ou no fim",
-    "Username must not consist of dots only" : "Nome do usuário não pode consistir de pontos somente",
-    "Username is invalid because files already exist for this user" : "O nome de usuário é inválido porque já exstem arquivos para este usuário",
-    "User disabled" : "Usuário desativado",
+    "The Login is already being used" : "O Login já está sendo usado",
+    "Could not create account" : "Não foi possível criar a conta",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Somente os seguintes caracteres são permitidos em um Login: \"a-z\", \"A-Z\", \"0-9\", espaços e \"_.@-'\"",
+    "A valid Login must be provided" : "Um login válido deve ser fornecido",
+    "Login contains whitespace at the beginning or at the end" : "O login contém espaços em branco no início ou no final",
+    "Login must not consist of dots only" : "O login não deve consistir apenas em pontos",
+    "Login is invalid because files already exist for this user" : "O login é inválido porque já existem arquivos para este usuário",
+    "Account disabled" : "Conta desativada",
     "Login canceled by app" : "Login cancelado pelo aplicativo",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "O aplicativo \"%1$s\" não pode ser instalado devido à estas dependências: %2$s",
     "a safe home for all your data" : "Um lar seguro para todos os seus dados",
@@ -244,10 +244,8 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Por favor peça ao administrador do servidor para reiniciar o servidor web.",
     "The required %s config variable is not configured in the config.php file." : "A variável %s de configuração necessária não está configurada no arquivo config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Peça ao administrador do servidor para verificar a configuração do Nextcloud.",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 é necessário.",
-    "Please upgrade your database version." : "Por favor, atualize a versão do seu banco de dados.",
-    "Your data directory is readable by other users." : "Seu diretório de dados pode ser lido por outros usuários.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor altere as permissões para 0770 para que o diretório não possa ser lido por outros usuários.",
+    "Your data directory is readable by other people." : "Seu diretório de dados pode ser lido por outras pessoas.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Altere as permissões para 0770 para que o diretório não possa ser listado por outras pessoas.",
     "Your data directory must be an absolute path." : "Seu diretório de dados deve ser um caminho absoluto.",
     "Check the value of \"datadirectory\" in your configuration." : "Verifique o valor de \"datadirectory\" em sua configuração.",
     "Your data directory is invalid." : "Seu diretório de dados é inválido.",
@@ -264,17 +262,37 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
     "Storage connection timeout. %s" : "Atingido o tempo limite de conexão ao armazenamento. %s",
     "Free prompt" : "Solicitação gratuita",
+    "Runs an arbitrary prompt through the language model." : "Executa um prompt arbitrário por meio do modelo de idioma.",
     "Generate headline" : "Gerar título",
     "Generates a possible headline for a text." : "Gera um título possível para um texto.",
     "Summarize" : "Resumir",
     "Summarizes text by reducing its length without losing key information." : "Resume o texto reduzindo seu comprimento sem perder informações importantes.",
     "Extract topics" : "Extrair tópicos",
     "Extracts topics from a text and outputs them separated by commas." : "Extrai tópicos de um texto e os gera separados por vírgulas.",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Os arquivos do aplicativo %1$s não foram instalados corretamente. Certifique-se que é uma versão compatível com seu servidor.",
-    "Full name" : "Nome completo ",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "O limite de usuários foi atingido e o usuário não foi criado. Verifique suas notificações para saber mais.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Somente os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\"",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "A libxml2 2.7.0 é a versão mínima necessária. Atualmente a versão %s está instalada.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Para corrigir este problema, atualize a versão da sua libxml2 e reinicie seu servidor web."
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuário conectado deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
+    "Logged in user must be an admin or sub admin" : "O usuário conectado deve ser um administrador ou subadministrador",
+    "Logged in user must be an admin" : "O usuário conectado deve ser um administrador",
+    "Help" : "Ajuda",
+    "Unknown user" : "Usuário desconhecido",
+    "Enter the database username and name for %s" : "Digite o nome de usuário e o nome do banco de dados para %s",
+    "Enter the database username for %s" : "Digite o nome de usuário do banco de dados para %s",
+    "MySQL username and/or password not valid" : "Nome de usuário e/ou senha do MySQL inválidos",
+    "Oracle username and/or password not valid" : "Nome de usuário e/ou senha Oracle inválidos",
+    "PostgreSQL username and/or password not valid" : "Nome de usuário e/ou senha PostgreSQL inválidos",
+    "Set an admin username." : "Defina um nome do usuário administrador.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Compartilhamento %s falhou, porque este item já está compartilhado com o usuário %s",
+    "The username is already being used" : "Este nome de usuário já está em uso",
+    "Could not create user" : "Não foi possível criar o usuário",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Apenas os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", espaços e \"_.@-'\"",
+    "A valid username must be provided" : "Um nome de usuário válido deve ser fornecido",
+    "Username contains whitespace at the beginning or at the end" : "O nome de usuário contém espaço em branco no início ou no fim",
+    "Username must not consist of dots only" : "Nome do usuário não pode consistir de pontos somente",
+    "Username is invalid because files already exist for this user" : "O nome de usuário é inválido porque já exstem arquivos para este usuário",
+    "User disabled" : "Usuário desativado",
+    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 é necessário.",
+    "Please upgrade your database version." : "Por favor, atualize a versão do seu banco de dados.",
+    "Your data directory is readable by other users." : "Seu diretório de dados pode ser lido por outros usuários.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor altere as permissões para 0770 para que o diretório não possa ser lido por outros usuários."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
